#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_IS_INCLUDED_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_IS_INCLUDED_HPP_INCLUDED

#include <boost/simd/reduction/include/functions/simd/is_included.hpp>

#endif
